Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3321)

Unified Diff: blimp/client/core/contents/blimp_contents_impl.h

Issue 2382733007: Add BlimpDocument, pull out functions in BlimpCompositor. (Closed)
Patch Set: Remove Webkit DEPS modification. Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « blimp/client/core/contents/android/blimp_view.cc ('k') | blimp/client/core/contents/blimp_contents_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: blimp/client/core/contents/blimp_contents_impl.h
diff --git a/blimp/client/core/contents/blimp_contents_impl.h b/blimp/client/core/contents/blimp_contents_impl.h
index a875c2457b083bab21bed51b6479704aae38cdd2..ae8862727167011158d9fa195535aeafedbe177b 100644
--- a/blimp/client/core/contents/blimp_contents_impl.h
+++ b/blimp/client/core/contents/blimp_contents_impl.h
@@ -7,10 +7,10 @@
#include "base/macros.h"
#include "base/observer_list.h"
-#include "blimp/client/core/compositor/blimp_compositor_manager.h"
#include "blimp/client/core/contents/blimp_contents_view_impl.h"
#include "blimp/client/core/contents/blimp_navigation_controller_delegate.h"
#include "blimp/client/core/contents/blimp_navigation_controller_impl.h"
+#include "blimp/client/core/render_widget/blimp_document_manager.h"
#include "blimp/client/public/contents/blimp_contents.h"
#include "ui/gfx/geometry/size.h"
#include "ui/gfx/native_widget_types.h"
@@ -80,16 +80,17 @@ class BlimpContentsImpl : public BlimpContents,
int id() { return id_; }
// TODO(nyquist): Remove this once the Android BlimpView uses a delegate.
- BlimpCompositorManager* compositor_manager() { return &compositor_manager_; }
+ BlimpDocumentManager* document_manager() { return &document_manager_; }
private:
// Handles the back/forward list and loading URLs.
BlimpNavigationControllerImpl navigation_controller_;
// Holds onto all active BlimpCompositor instances for this BlimpContents.
// This properly exposes the right rendered page content for the correct
// BlimpCompositor based on the engine state.
- BlimpCompositorManager compositor_manager_;
+ BlimpDocumentManager document_manager_;
// A list of all the observers of this BlimpContentsImpl.
base::ObserverList<BlimpContentsObserver> observers_;
« no previous file with comments | « blimp/client/core/contents/android/blimp_view.cc ('k') | blimp/client/core/contents/blimp_contents_impl.cc » ('j') | no next file with comments »
@@ -80,16 +80,17 @@ class BlimpContentsImpl : public BlimpContents,
// Handles the back/forward list and loading URLs.
BlimpNavigationControllerImpl navigation_controller_;
- // Holds onto all active BlimpCompositor instances for this BlimpContents.
+ // Holds onto all active BlimpDocument and BlimpCompositor instances for
+ // this BlimpContents.
// This properly exposes the right rendered page content for the correct
// BlimpCompositor based on the engine state.

Powered by Google App Engine
This is Rietveld 408576698